
# Slot: edge_list_separator


The separator to use for the edge list. Note that, if None is provided, one will be attempted to be detected automatically between ';', ',', tab or space.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_list_separator](https://w3id.org/neat/ensmallenRunConfig__edge_list_separator)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
